#
# spec file for package libfprint
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013 Mariusz Fik <fisiu@opensuse.org>.
# Copyright (c) 2021/22 Florian "sp1rit" <packaging@sp1rit.anonaddy.me>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define apiver 2
%define todapiver tod1

%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d}

# Systemd 248 and later already comes with the autosuspend hwdb
%if 0%{?suse_version} >= 1550
%define install_fp_udev_hwdb 0
%else
%define install_fp_udev_hwdb 1
%endif

Name:           libfprint
Version:        1.94.9+%{todapiver}
Release:        1.0.2.1.sr20250205
Summary:        Library for fingerprint reader support
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.freedesktop.org/wiki/Software/fprint
Source0:        https://gitlab.freedesktop.org/3v1n0/libfprint/-/archive/v%{version}/libfprint-v%{version}.tar.bz2
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE - fix compilation problem on < GCC 14
Patch0:         label-can-only-be-part-of-a-statement.patch
BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.56.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0) >= 2.68
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(gusb)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(udev)

%global _description %{expand:
The fprint project provides a central system to support fingerprint
readers. libfprint is the component which does the work of talking to
fingerprint reading devices, and processing fingerprint data.}

%description %{_description}

%package -n libfprint-%{apiver}-%{apiver}
Summary:        Library for fingerprint reader support
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      libfprint-examples

%description -n libfprint-%{apiver}-%{apiver} %{_description}

%package -n libfprint-%{apiver}-%{todapiver}
Summary:        Library for on-device verification fingerprint reader support
Group:          System/Libraries
Provides:       %{name}-tod = %{version}

%description -n libfprint-%{apiver}-%{todapiver} %{_description}

%package devel
Summary:        Headers for the fingerprint reader library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel
Requires:       libfprint-%{apiver}-%{apiver} = %{version}

%description devel
This package contains the header files and development documentation
for libfprint. If you like to develop programs using libfprint, you
will need to install this package.

%package tod-devel
Summary:        Headers for the fingerprint reader library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       %{name}-tod = %{version}
Requires:       libfprint-%{apiver}-%{todapiver}
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gudev-1.0)
Requires:       pkgconfig(gusb)
Requires:       pkgconfig(nss) >= 3.0
Requires:       pkgconfig(pixman-1)

%description tod-devel
This package contains the header files and development documentation
for libfprint. If you like to develop programs using libfprint, you
will need to install this package.

%package examples
Summary:        Example programs from the libfprint package
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description examples
This package contains example programs from libfprint.

%package doc
Summary:        Development documents of libfprint
Group:          Documentation/Other
BuildArch:      noarch

%description doc
This package contains the development documents for libfprint.

%package -n typelib-1_0-FPrint-2_0
Summary:        Introspection bindings for libfprint
Group:          System/Libraries

%description -n typelib-1_0-FPrint-2_0
This package contains the introspection bindings for the libfprint.

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
%meson \
	-Dgtk-examples=false \
	-Dinstalled-tests=false \
%if %{install_fp_udev_hwdb}
	-Dudev_hwdb=enabled \
%else
	-Dudev_hwdb=disabled \
%endif
	%{nil}
%meson_build

%install
%meson_install

%post -n libfprint-%{apiver}-%{apiver}
/sbin/ldconfig
%{?udev_rules_update:%udev_rules_update}
%if %{install_fp_udev_hwdb}
%{?udev_hwdb_update:%udev_hwdb_update}
%endif

%postun -n libfprint-%{apiver}-%{apiver} -p /sbin/ldconfig

%post -n libfprint-%{apiver}-%{todapiver} -p /sbin/ldconfig
%postun -n libfprint-%{apiver}-%{todapiver} -p /sbin/ldconfig

%files -n libfprint-%{apiver}-%{apiver}
%{_libdir}/%{name}-%{apiver}.so.*
%{_udevrulesdir}/70-%{name}-%{apiver}.rules
%if %{install_fp_udev_hwdb}
%{_udevhwdbdir}/60-autosuspend-%{name}-%{apiver}.hwdb
%endif

%files -n libfprint-%{apiver}-%{todapiver}
%{_libdir}/%{name}-%{apiver}-tod.so.*

%files -n typelib-1_0-FPrint-2_0
%{_libdir}/girepository-1.0/*.typelib

%files doc
%{_datadir}/gtk-doc/html/%{name}-%{apiver}
%{_datadir}/metainfo/org.freedesktop.libfprint.metainfo.xml

%files devel
%dir %{_includedir}/%{name}-%{apiver}
%{_includedir}/%{name}-%{apiver}/*.h
%{_libdir}/%{name}-%{apiver}.so
%{_libdir}/pkgconfig/%{name}-%{apiver}.pc
%{_datadir}/gir-1.0/*.gir

%files tod-devel
%{_includedir}/%{name}-%{apiver}/tod-1/
%{_libdir}/%{name}-%{apiver}-tod.so
%{_libdir}/pkgconfig/%{name}-%{apiver}-tod-1.pc

%changelog
* Fri Feb 21 2025 Arjen de Korte <suse+build@de-korte.org>
- update to 1.94.9+tod1
  * uru4000: Use OpenSSL to perform AES-ECB encryption, as per this
    libfprint does not support on NSS, but on openssl (>= 3.0).
  * goodixmoc: New PIDs 0x60C2, 0x689A
  * synaptics: New PIDs 0x016C, 0x0174, 0x0107, 0x0108, 0x00C2, 0x00F0
  * fpcmoc: New PID 0xC844
  * focaltech_moc: New PIDs 0xA99A, 0xA57A, 0xA78A
  * elanmoc: New PIDs 0x0C98, 0x0C9D, 0x0CA3
  * elanspi: New PIDs 0x3128, 0x2766
  * fp-device: Add FP_DEVICE_RETRY_TOO_FAST retry error
  * data: AppStream meta info listing supported USB devices.
  * fixed various memory issues in multiple devices
- rebase patch
  %% label-can-only-be-part-of-a-statement.patch
* Sun Oct 20 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.94.8+tod1
  * build: Support building in non-linux unix environments (tested in FreeBSD)
  * egismoc: New PIDs 0x0583, 0x0586, 0x0587.
  * elanmoc: New PID 0x0C9F.
  * fpcmoc: New PIDs 0x9524, 0x9544.
  * goodixmoc: New PIDs 0x609A, 0x650A, 0x650C, 0x6512.
  * realtek: New PID 0x5816.
  * synaptics: New PIDs 0x00C4, 0x019D, 0x00C6.
  * fpcmoc: fix incorrect immobile handling during enrollment.
  * fpcmoc: fixed jumping to wrong state at end of custom enroll.
  * egismoc: various code cleanups.
- fix compilation error
  + label-can-only-be-part-of-a-statement.patch
* Mon Mar 18 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 1.94.7+tod1
  * synaptics: fix enroll identify problem after user reset database.
  * synaptics: New PIDs 0x0173, 0x0106, 0x0124.
  * goodixmoc: New PID 0x6582.
  * build: Do not require bash to build, only posix sh.
  * fp-image: Simplify minutiae detection tasks.
  * GLib 2.68 is now required to build libfprint.
  * realtek (PID 0x5813).
  * focaltech_moc (PIDs 0x9E48, 0xD979, 0xA959).
  * egismoc (PIDs 0x0582, 0x05a1).
* Sun Aug 20 2023 Joshua Smith <jsmithfpv@gmail.com>
- update to 1.94.6+tod1:
  * goodixmoc: New PIDs 0x60A4, 0x60BC, 0x6092, 0x633C and 0x6304.
  * goodixmoc: Fix missing "enroll create" state.
  * elanmoc: New PID 0x0C99.
  * upektc: Improve compatibility with sensors 147e:2016.
  * aes4000: Actually support 08FF:5501 devices.
  * virtual-device-listener: Fix failing tests with GLib 2.76
  * tests: Add installed tests
  * Added installed TOD tests
  * #526 libfprint: fpcmoc: use after free if enrollment or
    identification is cancelled (Vasily Khoruzhick)
- New installed-tests is set to disabled
* Sun Nov  6 2022 Florian "spirit" <packaging@sp1rit.anonaddy.me>
- Move to libfprint-tod fork:
  This fork allows loading of external modules (typically non-free)
  located in /usr/lib64/libfprint-2/tod-1/. This is neccessary for
  fingerprint sensors that do on-device verifaction.
  These non-free modules shall be included in Packman repositories.
* Sat Oct 29 2022 Dirk Müller <dmueller@suse.com>
- update to 1.94.5:
  * New driver: fpcmoc, supporting various FPC MOC Fingerprint Sensors
  * goodixmoc: New PIDs 0x6014, 0x6094, 0x631C, 0x634C, 0x6384, 0x659A.
  * goodixmoc: Support resetting device on firmware failure due to corrupted DB.
  * elanmoc: New PIDs 0x0c88, 0x0c8c, 0x0c8d.
  * synaptics: New PID 0x0104.
  * upektc: New PID 0x2017.
  * Fixed various memory leaks
  * More tests
* Sun May 29 2022 Dirk Müller <dmueller@suse.com>
- update to 1.94.4:
  * synaptics: New PIDs 0x0168, 0x015f
  * elan: New PID 0x0c4b
  * elanspi: New PID 0x241f
  * synaptics: Minor fix to interrupt transfer resubmission
  * Avoid sysfs writes if value is already expected
  * Improvements to the testing setup
  * Fixes to the internal critical section API
* Sun Apr 24 2022 Dirk Müller <dmueller@suse.com>
- update to 1.94.3:
  * Ensure idle mainloop before completing enumeration (fprintd#119)
  * It is now possible to extend already enrolled prints
  * elanspi: Fix timeout error with some hardware (#438)
  * elanspi: Fix cancellation issues
  * goodixmoc: Return matching device print; fixes duplicate checking (#444)
  * goodixmoc: Support clearing the storage (usually unused)
* Tue Nov 16 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 1.94.2
  * Highlights:
    + goodixmoc: Fix protocol error with certain username lengths
    + elanmoc: New PID 0x0c7d
    + goodixmoc: New PID 0x63cc
- Changes from version 1.94.1
  * Highlights:
    + Ship a simple script to create new CI tests using tshark
    + Added CI tests for elan, uru4000, aes2501
    + goodixmoc: Remove duplicate checking during enroll and let fprintd handle it
    + uru4000: Fix USB transfer type
    + synaptics: Support for new PIDs
    + goodixmoc: Support for new PIDs
- Changes from version 1.94.0
  * Highlights:
    + Implement suspend/resume handling including USB wakeup configuration.
    + This requires writing the "persist" and "wakeup" sysfs attributes.
    + Add simple temperature module to prevent devices from becoming too hot
    + Add feature for continuous scanning
    + New internal "critical section" API to simplify driver development
    + elan: new PID 0x0c58
    + elanmoc: Fixes for multi-user handling and FW changes
    + virtual-device: Do not time out for SCAN command
* Sat Aug 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update descriptions, replace historic goals.
* Thu Aug  5 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update version to 1.92.1
  * Highlights:
    + elanmoc: New driver for ELAN match-on-chip devices
    + egis0570: New driver for some Egis Technology devices
    + synaptics: Fix empty identify causing enroll issues
    + elan: Support more PIDs
    + misc: Architecture related bugfixes
- Update version to 1.92.0
  * Highlights:
    + Support for SPI devices added together with the elanspi driver
    + Generate hwdb for autosuspend (which is now pulled by systemd)
    + An API was added to clear the device storage.
    + Note: Devices may not implement the "list" API anymore.
    + Device features can now be queried using a common API
  * New drivers:
    + vfs7552
    + nb1010
    + elanspi
  * For additional changes, see
    https://gitlab.freedesktop.org/libfprint/libfprint/-/releases#v1.92.1
* Thu Jan 14 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.90.7
  * vfs5011: Fix possible use-after-free
  * goodixmoc: Add two new PIDs (0x63AC, 0x639C)
  * goodixmoc: Support finger status API
  * synaptics: Only identify within provided prints
  * synaptics: Reject devices with old firmware during probe
* Thu Jan  7 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.90.6
  * Object reference management fixes for FpPrint and identify
  * Fixed issues that caused problem on non-x86 machines (#236)
  * Fix building with older GLib versions
  * synaptics: Support PID 00e7
  * goodix: Fix issue with long USB packages
- Update to version 1.90.5
  * Remove USB hub from udev autosupend rules
  * synaptics: Add PID 0x00c9 which is used in some HP laptops
- Update to version 1.90.4
  * Work around GUsb cancellation issue
  * Redefine internal image device state machine for more robustness
  * Add public finger-status reporting to FpDevice
  * Rework device removal API to be convenient (#330)
  * Enable powersave for unsupported USB devices
  * Improvements to examples
  * synaptics: Support identify operation
  * synaptics: Fix possible crash when the interrupt transfer is
    resubmitted
  * synaptics: Add support for PIDs 0x00f9, 0x00fc and 0x00c2
  * elan: Add PID 0x0c4d to supported device list
  * aes3k: Fix driver and add CI test (#306)
  * uru4000: Fix reference counting of image transfer
  * vfs301: Fix driver and add CI test (#320)
* Sun Sep 27 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.90.3:
  * New goodixmoc driver supporting Goodix USB devices: 27C6:5840 27C6:6496 27C6:60A2
  * Newly added support for Synaptics device: 06CB:00E9 06CB:00DF
  * Fixed an issue with Synaptics devices sometimes not working at boot
  * Fix issue with aes3k driver (#306)
  * A patch for nbis required for some sensors was accidentally dropped in an earlier release
  Users of these sensors/drivers need to re-enroll
* Thu Apr 30 2020 Axel Braun <axel.braun@gmx.de>
- gobject-introspection-devel added to fix TW build error
* Sun Mar 15 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.90.1
  * Library:
  * Add early report mechanism for verify and identify (API CHANGE!)
  * Add support to run tests in gdb/valgrind
  * Allow testing on all architectures
  * Avoid image device AWAIT_FINGER_ON to deactivate state transitions
  * Fix verify/identify error propagation to library user
  * Correctly read image device information from class data
  * Continue enroll after an image driver reported a retry error
  * Change external API to allow reporting match results early
  * A lot of new unit tests and integration tests have been added
  * Drivers API:
  * Added API for early report of matching results or retry errors
  * Verify and identification completion functions have been simplified
  * Support variadic arguments in error functions
  * Various re-definitions of ownership handling
  * Add convenience API to change state after a timeout
  * Add unit tests for all the drivers API
  * Drivers:
  * elan: Ensure correct deactivation of device
  * uru4000: Fix IRQ handler registration and internal state handling
  * uru4000: Fix control transfer request type
  * synaptics:
    Ensure errors are only reported after finger removal
    Use early report mechanism
- Enable documents build
* Fri Nov 29 2019 Johannes Kastl <kastl@b1-systems.de>
- update to 1.0:
  * Library:
  * Add guards to the public API and require GLib 2.50
  * Deprecate print storage API
  * Better documentation for fp_discover_devs()
  * Remove unused internal fpi_timeout_cancel_for_dev()
  * Remove state from fp_img_driver activate handler
  * Bug fixes related to restarting a failed verification immediately
  * Drivers:
  * The Elan driver received a lot of bug fixes including a fix for a hang when verifying prints with fprintd, quirks for some devices, a memory leak fix and support for 04f3:0c42
  * Fix a probable crash in all the AES drivers
  * Add support for Lenovo Preferred Pro Keyboard (KUF1256) to vfs5011
  * Prevent hang during enroll process in etes603 driver
  * Fix possible integer overflow in uru4000
  * Work-around SELinux AVC warnings when uru4000 driver starts
  * Remove long-unmaintained and broken fdu2000 driver
  * Tools/Examples:
  * Fix examples not working due to an overly strict check
  * Fix crash in GTK demo when there's no supported devices
  * Disable GTK demo until we have a USB Flatpak portal
  * Remove sleep() in enroll example which caused a crash in some drivers
  * Add a simple storage implementation example
* Sat Dec 15 2018 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.99.0:
  + Library:
  - All the internal API for device driver writers is now covered
    by the documentation and has been enhanced to make it easier
    to write drivers.
  - Update internal NBIS fingerprint data processing library to
    one that's nearly 10 years newer.
  - Re-add accessor for minutia coordinates which was used in the
    very old fprint_demo program, but also by our new GTK+ test
    program (see below).
  - Fix a crash when too many minutiae were detected in a
    capture.
  + Drivers: Support more devices in the Elan driver, stability
    improvements.
  + Tools: Add a test GTK+ application that will eventually be used
    for testing drivers without modifying the OS installed version.
    Note that this application currently requires manually changing
    permissions of USB devices, this will be fixed when the
    infrastructure exists to access those devices without
    additional permissions, as a normal user.
- Changes from version 0.8.2:
  + Drivers:
  - Add USB ID for TNP Nano USB Fingerprint Reader.
  - Fix UPEKTS enrollment never finishing on some devices.
  + Library:
  - Fix fp_get_pollfds() retval type, a small ABI change
  - Downgrade fatal errors to run-time warnings, as a number of
    drivers used to throw silent errors and we made them fatal.
    Those will now be visible warnings, hopefully helping with
    fixing them.
- Changes from version 0.8.1:
  + Brown paperbag release to install the udev rules file in the
    correct directory if the udev pkg-config file doesn't have a
    trailing slash.
- Changes from version 0.8.0:
  + Port to meson as the build system.
  + Port documentation to gtk-doc.
  + Drivers:
  - Add Elan driver
  - Increase threshold to detect encryption on URU4000 devices.
  - Remove already replaced UPEKE2 driver.
  - Fix possible crash caused by vfs5011 when no lines were
    captured.
  + Library:
  - Fix a number of memory and file descriptor leaks and
    warnings.
  - Make NSS (and URU4000) driver optional.
  - Fix assembling of frames for non-reverse and non reverse
    stripes.
  - Split internal private header to clarify drivers API.
  - Simplify logging system, now all the builds can be used to
    output debug information.
  - Mark fp_dscv_print functions as deprecated.
  + Udev rules: Add some unsupported devices to the whitelist.
- Changes from version 0.7.0:
  + Drivers:
  - Add VFS0050 driver.
  - Fix possible crash in AES3500 and AES4000.
  - Fix broken enrollment in VFS101.
  - Better verification with small sensor scanners.
  - Plenty of fixes in VFS5011.
  - Fix memory corruption in AES1610.
  - Improve calibration settings for AES1610.
  - Improve image assembling in upeksonly driver.
  - Autodetect whether image is encrypted in uru4k.
  + Library:
  - NBIS: Remove false minutia at the edge of partial image.
  - Introduce routines to assemble image from lines (used in
    VFS5011 and upeksonly).
  - Fix a bug that can cause driver state machine to enter into
    endless loop.
  + Udev rules: Add driver name to the USB properties.
  + Plenty of build fixes.
- Switch to meson buildsystem, add meson BuildRequires and macros
  following upstreams port.
- Drop automake and libtool BuildRequires, no longer needed.
- Run spec-cleaner, modernize spec, use modern macros.
- Drop libfprint-upeke2_6stage.diff and
  libfprint-install_examples.patch: No longer needed, nor applies
  due to upstream changes.
- Drop _service file, upstream moved to gitlab, and have unique
  download urls now, so service file no longer usefull.
- Drop examples subpackage and obsolete it, follow fedoras
  packaging lead here.
* Sat Feb  7 2015 p.drouand@gmail.com
- Update to version 0.6.0
  * Drivers:
  - Reduce duplication between AES3500 and AES4000 drivers and
    add support for AES3500 device
  - Add support for UPEK 147e:2020 and Upek Eikon 2 devices
  - Add EgisTec ES603 driver
  - Add VFS5011 driver
  - Always perform 5 scans for image enrollment
  - Better verification with AES1660 driver
  - Better verification for a number of AES drivers
  * Library:
  - Always use Pixman for image manipulation, gdk-pixbuf and ImageMagick
    are not supported any more.
  * Udev rules:
  - Fix warning when USB hub or system does not support power management
- Add pkgconfig(pixman-1) build require; new upstream dependency
- Remove pkgconfig(gdk-pixbuf-2.0) build require; not needed anymore
* Sun Nov 24 2013 crrodriguez@opensuse.org
-  define _udevrulesdir only if not already in place.
- run %%udev_rules_update if such macro is defined
* Sat Sep 21 2013 mailaender@opensuse.org
- Update to version 0.5.1:
  + Add support for 147e:2020 to upeke2 driver
  + Fix possible race condition, and cancellation in uru4000 driver
  + Add Microsoft keyboard to the suspend blacklist
  + Plenty of build fixes
- Adhere to https://en.opensuse.org/SourceUrls
- Rebased libfprint-install_examples.patch
- Removed libfprint-upeke2_add_147e_2020_id_support.patch as it is included now.
* Mon May 20 2013 suse@bugs.jan.ritzerfeld.org
- upeke2: Add support for 147e:2020 ID (fdo#59320)
* Wed Apr 17 2013 idonmez@suse.com
- Fix file conflicts
* Sun Apr 14 2013 crrodriguez@opensuse.org
- fix -devel package requires,nowhere this library requires
  pkgconfig(ImageMagick), pkgconfig(glib-2.0), pkgconfig(libusb-1.0)
  pkgconfig(openssl), pkgconfig(zlib), not at linking time, not at
  the headers..
* Thu Apr 11 2013 crrodriguez@opensuse.org
- Place udev rules in the correct directory.
* Mon Apr  1 2013 fisiu@opensuse.org
- Update to version 0.5.0:
  + Drivers:
  - New VFS300/VFS301 driver
  - New AES2550/AES2810 drivers
  - New AES1660 driver
  - New AES2660 driver
  - New DigitalPersona URU4500 driver
  - Avoid empty capture and improve image contrast in the
    AES2501 and AES2550 drivers
  - Update upektc driver, add support for Eikon Touch 300
  - Fix UrU4000 image capture on ARM
  + Library:
  - Fix global variable collisions with libusb and other system
    headers
  - Fix possible crash in NBIS image processing with some
    fingerprints
  + Udev rules:
  - Fix power control path for newer kernels
  - Move udev rules to the correct directory
  - Don't print duplicated udev rules
  - Include udev rules in the tarball
  - Allow disabling of udev rules for cross-compiling
  - Add driver names in the generated rules
* Wed Sep  5 2012 p.drouand@gmail.com
- Release 0.4.0 :
  * Add support for Validity VFS101 (USB ID 138a:0001)
  * Fix crasher when resizing a fingerprint image
  * Fix wrong timeout being returned when either of
  libusb or libfprint doesn't have a timeout
- Remove unnecessary "obsoletes" and "provides" libfprint0 package entries
- Fix URL
* Mon Aug 27 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  No LGPL-2.1 "only" licenses found in the package
* Sun May 20 2012 zaitor@opensuse.org
- Add libtool as buildrequires.
- Run autoreconf -fi before ./configure due to
  libfprint-install_examples.patch, fixes build on factory.
- Listing files in subpackage examples explicitly so we don't loose
  any on future upgrades.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Sep 16 2011 andrea.turrini@gmail.com
- fix typos in description
* Thu Nov 11 2010 coolo@novell.com
- own parent directories of udev rules
* Thu Oct  7 2010 fcrozat@novell.com
- Release 0.3.0 (since 0.1.0-pre2):
  * Add support for UPEK TCS4C (USB ID 147e:1000)
  * Use NSS instead of OpenSSL for GPL compliance
  * upeksonly driver bug fixes
  * Fix a crash if a scan was shorter than 8 lines
  * Fix compilation with C++ compiler
  * Add gdk-pixbuf support for image manipulation
  * Add udev rules to allow devices to autosuspend
  * Finish port of AES1610 driver
  * Add UPEK EikonII (TCRD4C) driver
- update libfprint-install_examples.patch
- do not package .la files
* Wed Sep 29 2010 ro@suse.de
- install examples correctly
* Mon Aug  9 2010 ro@suse.de
- add examples subpackage
* Thu Aug  5 2010 ro@suse.de
- work to support 147e:2016 (Upek Eikon 2 as in T410)
- update to 0.1.0-pre2
- add fedora patches
- add patches from brc#504399
- fix udev rule install
- fix enroll_retcode to accept 0x2e as well in upekts and upeke2
- my scanner needs full 5 passes, so set nr_enroll_stages to 6
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Tue May 12 2009 thoenig@suse.de
- run autoreconf -fi before ./configure
* Tue Jan 27 2009 thoenig@suse.de
- add libfprint-deinit-01.patch: Add new function fp_dev_reset used
  to settle the USB device if it was driven into a undefined state.
  (bnc#463557)
* Wed Nov  5 2008 thoenig@suse.de
- move supplementing USB IDs from libfprint0 to pam_fp (bnc#441754)
* Tue Oct 28 2008 thoenig@suse.de
- libfprint0 provide/obsoletes libthinkfinger
* Thu Oct 23 2008 thoenig@suse.de
- generate HAL fdi so that fingerprint readers are properly
  recognized (bnc#438187)
* Mon Oct 13 2008 thoenig@suse.de
- move 'supplements' and 'recommends' to libfprint0
* Thu Oct  9 2008 thoenig@suse.de
- use uppercase for hexadecimal numbers in USB vendor and product
  IDs
* Mon Oct  6 2008 thoenig@suse.de
- add supplements for supported USB devices
- add baselibs.conf (libfprint0) as pam_fp requires libfprint
- fix header for inclusions in C++
* Fri Sep  5 2008 thoenig@suse.de
- initial check-in
